==> SharpSK%201.6.1.2.src.zip: SharpSK-1.6.1.2/src/main/java/me/sharpjaws/sharpSK/hooks/LightAPI/EffDeleteLight.java <==
package me.sharpjaws.sharpSK.hooks.LightAPI;

import java.util.List;

import javax.annotation.Nullable;

import org.bukkit.Bukkit;
import org.bukkit.Location;
import org.bukkit.event.Event;

import ch.njol.skript.lang.Effect;
import ch.njol.skript.lang.Expression;
import ch.njol.skript.lang.SkriptParser;
import ch.njol.util.Kleenean;
import ru.beykerykt.lightapi.LightAPI;
import ru.beykerykt.lightapi.chunks.ChunkInfo;

public class EffDeleteLight extends Effect {
	private Expression<Location> loc;
	private Expression<Boolean> async;
	
	@SuppressWarnings("unchecked")
	@Override
	public boolean init(Expression<?>[] expr, int matchedPattern, Kleenean paramKleenean,
			SkriptParser.ParseResult paramParseResult) {
		loc = (Expression<Location>) expr[0];
		async = (Expression<Boolean>) expr[1];
		return true;
	}

	@Override
	public String toString(@Nullable Event paramEvent, boolean paramBoolean) {
		return "delete light at %location%";
	}

	@Override
	protected void execute(Event e) {
		if (Bukkit.getPluginManager().getPlugin("LightAPI").getDescription().getVersion().contains("3.0.0")){
			LightAPI.deleteLight(loc.getSingle(e), async.getSingle(e));
			for(ChunkInfo info: LightAPI.collectChunks(loc.getSingle(e).getWorld(), loc.getSingle(e).getBlockX(), loc.getSingle(e).getBlockY(), loc.getSingle(e).getBlockZ())){
				LightAPI.updateChunks(info);
			}
		}else{	
			LightAPI.deleteLight(loc.getSingle(e), async.getSingle(e));
			for(ChunkInfo info: LightAPI.collectChunks(loc.getSingle(e).getWorld(), loc.getSingle(e).getBlockX(), loc.getSingle(e).getBlockY(), loc.getSingle(e).getBlockZ())){
				LightAPI.updateChunk(info);
		}
		 }
	  }
}

==> SharpSK%201.6.2.1.src.zip: SharpSK-1.6.2.1/src/main/java/me/sharpjaws/sharpSK/hooks/LightAPI/EffDeleteLight.java <==
package me.sharpjaws.sharpSK.hooks.LightAPI;

import java.util.List;

import javax.annotation.Nullable;

import org.bukkit.Bukkit;
import org.bukkit.Location;
import org.bukkit.event.Event;

import ch.njol.skript.lang.Effect;
import ch.njol.skript.lang.Expression;
import ch.njol.skript.lang.SkriptParser;
import ch.njol.util.Kleenean;
import ru.beykerykt.lightapi.LightAPI;
import ru.beykerykt.lightapi.chunks.ChunkInfo;

public class EffDeleteLight extends Effect {
	private Expression<Location> loc;
	private Expression<Boolean> async;
	
	@SuppressWarnings("unchecked")
	@Override
	public boolean init(Expression<?>[] expr, int matchedPattern, Kleenean paramKleenean,
			SkriptParser.ParseResult paramParseResult) {
		loc = (Expression<Location>) expr[0];
		async = (Expression<Boolean>) expr[1];
		return true;
	}

	@Override
	public String toString(@Nullable Event paramEvent, boolean paramBoolean) {
		return "delete light at %location%";
	}

	@Override
	protected void execute(Event e) {
		if (Bukkit.getPluginManager().getPlugin("LightAPI").getDescription().getVersion().matches("3.\\d.\\d")){
			LightAPI.deleteLight(loc.getSingle(e), async.getSingle(e));
			for(ChunkInfo info: LightAPI.collectChunks(loc.getSingle(e).getWorld(), loc.getSingle(e).getBlockX(), loc.getSingle(e).getBlockY(), loc.getSingle(e).getBlockZ())){
				LightAPI.updateChunk(info);
			}
		}else{	
			LightAPI.deleteLight(loc.getSingle(e), async.getSingle(e));
			for(ChunkInfo info: LightAPI.collectChunks(loc.getSingle(e).getWorld(), loc.getSingle(e).getBlockX(), loc.getSingle(e).getBlockY(), loc.getSingle(e).getBlockZ())){
				LightAPI.updateChunk(info);
		}
		 }
	  }
}
